pitchtools.PitchObject
======================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__abs__

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__float__

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__ge__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__gt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__hash__

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__int__

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__le__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__lt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__ne__

.. automethod:: abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject.__repr__
